@@ -49,20 +49,22 @@ static const GOptionEntry options[] = {
     { "no-daemonize", 'd', 0, G_OPTION_ARG_NONE, &agent_no_daemonize, 
         N_("Do not daemonize seahorse-agent"), NULL },
 
+    /* TRANSLATORS: An example of a 'C type shell' is 'csh' often used by *BSD instead of bash */
     { "cshell", 'c', 0, G_OPTION_ARG_NONE, &seahorse_agent_cshell, 
         N_("Print variables in for a C type shell"), NULL },
 
     { "variables", 'v', 0, G_OPTION_ARG_NONE, &seahorse_agent_displayvars, 
-        N_("Display variables instead of editing conf files (gpg.conf, ssh agent socket)"), NULL },
+        N_("Display variables instead of editing conf files (gpg.conf, SSH agent socket)"), NULL },
 
     { "execute", 'x', 0, G_OPTION_ARG_NONE, &seahorse_agent_execvars, 
         N_("Execute other arguments on the command line"), NULL },
       
+    /* TRANSLATORS: A 'display' is a an X display */
     { "any-display", 'A', 0, G_OPTION_ARG_NONE, &seahorse_agent_any_display, 
         N_("Allow GPG agent request from any display"), NULL },
       
     { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &agent_exec_args, 
-        NULL, N_("command ...") },
+        NULL, N_("command...") },
 
     { NULL }
 };
@@ -224,6 +226,10 @@ int main(int argc, char* argv[])
 #endif
         err (1, _("couldn't drop privileges properly"));
     
+    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
+    
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
 
