@@ -49,60 +49,39 @@ typedef struct _SeahorseServiceClass SeahorseServiceClass;
 #define SEAHORSE_SERVICE_GET_CLASS(object)  (G_TYPE_INSTANCE_GET_CLASS((object), SEAHORSE_TYPE_SERVICE, SeahorseServiceClass))
 
 struct _SeahorseService {
-	GObject base;
+    GObject base;
     
     /* <public> */
     GHashTable *keysets;
 };
 
 struct _SeahorseServiceClass {
-	GObjectClass base;
+    GObjectClass base;
 };
 
-GType          seahorse_service_get_type            (void);
+GType          seahorse_service_get_type              (void);
 
-gboolean       seahorse_service_get_key_types       (SeahorseService *svc, gchar*** ret, 
-                                                     GError **error);
+gboolean       seahorse_service_get_key_types         (SeahorseService *svc, gchar*** ret, 
+                                                       GError **error);
 
+gboolean        seahorse_service_get_keyset           (SeahorseService *svc, gchar *ktype, 
+                                                       gchar **path, GError **error);
 
-gboolean        seahorse_service_get_keyset         (SeahorseService *svc, gchar *ktype, 
-                                                     gchar **path, GError **error);
-
-gboolean        seahorse_service_has_key_field      (SeahorseService *svc, gchar *key, 
-                                                     gchar *field, gboolean *has, GError **error);
-
-gboolean        seahorse_service_get_key_field      (SeahorseService *svc, gchar *key, 
-                                                     gchar *field, GValue *value, GError **error);
-
-gboolean        seahorse_service_get_key_fields     (SeahorseService *svc, gchar *key, 
-                                                     gchar **fields, GHashTable **values, GError **error);
-
-gboolean        seahorse_service_get_key_names      (SeahorseService *svc, gchar *key, 
-                                                     gchar ***names, gchar ***cns, GError **error);
-
-gboolean        seahorse_service_import_keys        (SeahorseService *svc, gchar *ktype, 
-                                                     gchar *data, gchar ***keys, GError **error);
+gboolean        seahorse_service_import_keys           (SeahorseService *svc, gchar *ktype, 
+                                                        gchar *data, gchar ***keys, GError **error);
                               
-gboolean        seahorse_service_export_keys        (SeahorseService *svc, gchar *ktype,
-                                                     gchar **keys, gchar **data, GError **error);
+gboolean        seahorse_service_export_keys           (SeahorseService *svc, gchar *ktype,
+                                                        gchar **keys, gchar **data, GError **error);
 
-gboolean        seahorse_service_match_keys         (SeahorseService *svc, gchar *ktype, 
-                                                     gint flags, gchar **patterns, gchar ***keys, 
-                                                     gchar***unmatched, GError **error);
+gboolean        seahorse_service_display_notification  (SeahorseService *svc, gchar *heading,
+                                                        gchar *text, gchar *icon, 
+                                                        gboolean urgent, GError **error);
 
-gboolean        seahorse_service_match_save         (SeahorseService *svc, gchar *ktype, 
-                                                     gint flags, gchar **patterns, 
-                                                     gchar **keys, GError **error);
-
-gboolean        seahorse_service_discover_keys      (SeahorseService *svc, gchar *ktype, 
-                                                     gint flags, gchar **patterns, gchar **keys, 
-                                                     GError **error);
-
-SeahorseKey*    seahorse_service_key_from_dbus      (const gchar *key, guint *uid);
-
-gchar*          seahorse_service_key_to_dbus        (SeahorseKey *skey, guint uid);
-
-gchar*          seahorse_service_keyid_to_dbus      (GQuark ktype, const gchar *keyid, guint uid);
+#if 0
+gboolean        seahorse_service_match_save            (SeahorseService *svc, gchar *ktype, 
+                                                        gint flags, gchar **patterns, 
+                                                        gchar **keys, GError **error);
+#endif
 
 /* -----------------------------------------------------------------------------
  * KEYSET SERVICE
@@ -120,6 +99,9 @@ typedef struct _SeahorseServiceKeysetClass SeahorseServiceKeysetClass;
 
 struct _SeahorseServiceKeyset {
     SeahorseKeyset base;
+    
+    /* <public> */
+    GQuark ktype;
 };
 
 struct _SeahorseServiceKeysetClass {
@@ -139,11 +121,30 @@ struct _SeahorseServiceKeysetClass {
 
 GType           seahorse_service_keyset_get_type       (void);
 
-SeahorseKeyset* seahorse_service_keyset_new            (GQuark keytype);
+SeahorseKeyset* seahorse_service_keyset_new            (GQuark keytype, 
+                                                        SeahorseKeyLoc location);
 
 gboolean        seahorse_service_keyset_list_keys      (SeahorseServiceKeyset *keyset,
                                                         gchar ***keys, GError **error);
 
+gboolean        seahorse_service_keyset_get_key_field  (SeahorseService *svc, gchar *key, 
+                                                        gchar *field, gboolean *has, 
+                                                        GValue *value, GError **error);
+
+gboolean        seahorse_service_keyset_get_key_fields (SeahorseService *svc, gchar *key, 
+                                                        gchar **fields, GHashTable **values, 
+                                                        GError **error);
+
+gboolean        seahorse_service_keyset_discover_keys  (SeahorseServiceKeyset *keyset, 
+                                                        const gchar **keyids, gint flags,
+                                                        gchar ***keys, GError **error);
+
+
+gboolean        seahorse_service_keyset_match_keys     (SeahorseServiceKeyset *keyset, 
+                                                        gchar **patterns, gint flags, 
+                                                        gchar ***keys, gchar***unmatched, 
+                                                        GError **error);
+
 /* -----------------------------------------------------------------------------
  * CRYPTO SERVICE
  */
