@@ -507,6 +507,8 @@ seahorse_context_take_key (SeahorseContext *sctx, SeahorseKey *skey)
     
     g_return_if_fail (SEAHORSE_IS_CONTEXT (sctx));
     g_return_if_fail (SEAHORSE_IS_KEY (skey));
+    g_return_if_fail (skey->keyid != 0);
+    g_return_if_fail (!skey->attached_to);
     
     ks = hashkey_by_source (seahorse_key_get_source (skey), 
                             seahorse_key_get_keyid (skey));
@@ -514,6 +516,8 @@ seahorse_context_take_key (SeahorseContext *sctx, SeahorseKey *skey)
     g_return_if_fail (!g_hash_table_lookup (sctx->pv->keys_by_source, ks));
 
     g_object_ref (skey);
+
+    skey->attached_to = sctx;
     g_hash_table_replace (sctx->pv->keys_by_source, ks, skey);
     setup_keys_by_type (sctx, skey, TRUE);
     g_signal_emit (sctx, signals[ADDED], 0, skey);
@@ -636,6 +640,12 @@ seahorse_context_find_keys_full (SeahorseContext *sctx, SeahorseKeyPredicate *sk
     return km.keys; 
 }
 
+gboolean
+seahorse_context_owns_key (SeahorseContext *sctx, SeahorseKey *skey)
+{
+    return skey->attached_to == sctx;
+}
+
 void 
 seahorse_context_remove_key (SeahorseContext *sctx, SeahorseKey *skey)
 {
@@ -648,9 +658,12 @@ seahorse_context_remove_key (SeahorseContext *sctx, SeahorseKey *skey)
                            seahorse_key_get_keyid (skey));
     
     if (g_hash_table_lookup (sctx->pv->keys_by_source, k)) {
+        g_return_if_fail (skey->attached_to == sctx);
+
         g_object_ref (skey);
         g_signal_handlers_disconnect_by_func (skey, key_changed, sctx);
         g_signal_handlers_disconnect_by_func (skey, key_destroyed, sctx);
+        skey->attached_to = NULL;
         g_hash_table_remove (sctx->pv->keys_by_source, k);
         setup_keys_by_type (sctx, skey, FALSE);
         g_signal_emit (sctx, signals[REMOVED], 0, skey);    
@@ -721,7 +734,7 @@ seahorse_context_load_local_keys (SeahorseContext *sctx)
                 seahorse_multi_operation_take (mop, op);
             }
             
-            op = seahorse_key_source_load (ks, SKSRC_LOAD_ALL, 0, NULL);
+            op = seahorse_key_source_load (ks, 0);
             
             if (mop != NULL)
                 seahorse_multi_operation_take (mop, op);
@@ -731,6 +744,22 @@ seahorse_context_load_local_keys (SeahorseContext *sctx)
     return mop ? SEAHORSE_OPERATION (mop) : op;  
 }
 
+static gboolean 
+load_local_keys (SeahorseContext *sctx)
+{
+    SeahorseOperation *op = seahorse_context_load_local_keys (sctx);
+    g_return_val_if_fail (op != NULL, FALSE);
+    g_object_unref (op);
+    return FALSE;
+}
+
+void
+seahorse_context_load_local_keys_async (SeahorseContext *sctx)
+{
+    g_idle_add_full (G_PRIORITY_LOW, (GSourceFunc)load_local_keys, sctx, NULL);
+}
+
+
 SeahorseOperation*  
 seahorse_context_load_remote_keys (SeahorseContext *sctx, const gchar *search)
 {
@@ -772,7 +801,7 @@ seahorse_context_load_remote_keys (SeahorseContext *sctx, const gchar *search)
             seahorse_multi_operation_take (mop, op);
         }
             
-        op = seahorse_key_source_load (ks, SKSRC_LOAD_SEARCH, 0, search);
+        op = seahorse_key_source_search (ks, search);
             
         if (mop != NULL)
             seahorse_multi_operation_take (mop, op);
@@ -1038,7 +1067,7 @@ seahorse_context_discover_keys (SeahorseContext *sctx, GQuark ktype,
     }
     
     /* Start a discover process on all todiscover */
-    if (todiscover) {
+    if (seahorse_gconf_get_boolean (AUTORETRIEVE_KEY) && todiscover) {
         op = seahorse_context_retrieve_keys (sctx, ktype, todiscover, NULL);
 
         /* Add unknown keys for all these */
