@@ -26,8 +26,6 @@
 #include "seahorse-util.h"
 #include "seahorse-pgp-key.h"
 #include "seahorse-ssh-key.h"
-#include "seahorse-generate-adv.h"
-#include "seahorse-generate-druid.h"
 #include "seahorse-key-dialogs.h"
 #include "seahorse-gtkstock.h"
 
@@ -53,14 +51,8 @@ choose_keytype(SeahorseWidget *swidget)
     GtkTreeSelection *selection;
     SeahorseKeySource *sksrc;
     GtkTreeIter iter;
-    gboolean advanced;
     GQuark ktype;
 
-    /* Advanced or not? */
-    widget = seahorse_widget_get_widget (swidget, "advanced-option");
-    g_return_if_fail (widget != NULL);
-    advanced = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-    
     /* Figure out the key type selected */
     widget = seahorse_widget_get_widget (swidget, "keytype-tree");
     g_return_if_fail (widget != NULL);
@@ -73,22 +65,18 @@ choose_keytype(SeahorseWidget *swidget)
     sksrc = seahorse_context_find_key_source (SCTX_APP (), ktype, SKEY_LOC_LOCAL);
     g_return_if_fail (sksrc != NULL);
     
-    seahorse_widget_destroy (swidget);
-    
-    if (ktype == SKEY_PGP) {
-        if (advanced)
-            seahorse_generate_adv_show ();
-        else
-            seahorse_generate_druid_show ();
+    if (ktype == SKEY_PGP)
+        seahorse_pgp_generate_show (SEAHORSE_PGP_SOURCE (sksrc), GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
         
-    } 
 #ifdef WITH_SSH 
     else if (ktype == SKEY_SSH)
-        seahorse_ssh_generate_show (SEAHORSE_SSH_SOURCE (sksrc));
+        seahorse_ssh_generate_show (SEAHORSE_SSH_SOURCE (sksrc), GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 #endif 
     
     else
         g_return_if_reached ();
+
+    seahorse_widget_destroy (swidget);
 }
 
 static void
@@ -131,7 +119,7 @@ add_key_type (GtkListStore *store, GQuark type, const char *stock_icon,
 }
 
 void
-seahorse_generate_select_show ()
+seahorse_generate_select_show (GtkWindow *parent)
 {
     SeahorseWidget *swidget;
     GtkListStore *store;
@@ -140,7 +128,7 @@ seahorse_generate_select_show ()
     GtkTreeIter iter;
     GtkWidget *widget;
     
-    swidget = seahorse_widget_new ("generate-select");
+    swidget = seahorse_widget_new ("generate-select", parent);
     
     /* Widget already exists */
     if (swidget == NULL)
@@ -154,7 +142,7 @@ seahorse_generate_select_show ()
     add_key_type (store, SKEY_PGP, SEAHORSE_STOCK_SECRET, _("PGP Key"), 
                   _("Used to encrypt email and files"));
 #ifdef WITH_SSH
-    add_key_type (store, SKEY_SSH, SEAHORSE_STOCK_KEY_SSH, _("SSH Key"),
+    add_key_type (store, SKEY_SSH, SEAHORSE_STOCK_KEY_SSH, _("Secure Shell Key"),
                   _("Used to access other computers (eg: via a terminal)"));
 #endif /* WITH_SSH */
     
