@@ -112,7 +112,7 @@ SeahorseKeyPredicate pred_password = {
 #define SEC_RING "/secring.gpg"
 #define PUB_RING "/pubring.gpg"
 
-static void selection_changed (GtkTreeSelection *notused, SeahorseWidget *swidget);
+static gboolean selection_changed (SeahorseWidget *swidget);
 
 /* SIGNAL CALLBACKS --------------------------------------------------------- */
 
@@ -220,7 +220,7 @@ set_current_tab (SeahorseWidget *swidget, guint tabid)
         if (get_tab_id (gtk_notebook_get_nth_page (notebook, i)) == tabid)
         {
             gtk_notebook_set_current_page (notebook, i);
-            selection_changed (NULL, swidget);
+            selection_changed (swidget);
             return;
         }
     }
@@ -353,19 +353,19 @@ set_numbered_status (SeahorseWidget *swidget, const gchar *message, guint num)
 
 /* Shows the properties for a given key */
 static void
-show_properties (SeahorseKey *skey)
+show_properties (SeahorseKey *skey, GtkWindow *parent)
 {
     g_assert (skey);
     
     if (SEAHORSE_IS_PGP_KEY (skey))
-        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey));
+        seahorse_key_properties_new (SEAHORSE_PGP_KEY (skey), parent);
 #ifdef WITH_SSH    
     else if (SEAHORSE_IS_SSH_KEY (skey))
-        seahorse_ssh_key_properties_new (SEAHORSE_SSH_KEY (skey));
+        seahorse_ssh_key_properties_new (SEAHORSE_SSH_KEY (skey), parent);
 #endif 
 #ifdef WITH_GNOME_KEYRING
     else if (SEAHORSE_IS_GKEYRING_ITEM (skey))
-        seahorse_gkeyring_item_properties_new (SEAHORSE_GKEYRING_ITEM (skey));
+        seahorse_gkeyring_item_properties_new (SEAHORSE_GKEYRING_ITEM (skey), parent);
 #endif
 }
 
@@ -373,14 +373,14 @@ show_properties (SeahorseKey *skey)
 static void
 generate_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
-    seahorse_generate_select_show ();
+    seahorse_generate_select_show (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 /* Loads Key generation assistant for first time users */
 static void
 new_button_clicked (GtkWidget *widget, SeahorseWidget *swidget)
 {
-    seahorse_generate_select_show ();
+    seahorse_generate_select_show (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 static void
@@ -611,7 +611,7 @@ properties_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
 	SeahorseKey *skey = get_selected_key (swidget, NULL);
 	if (skey != NULL)
-        show_properties (skey);
+        show_properties (skey, GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
 static void
@@ -727,14 +727,16 @@ sign_activate (GtkWidget *widget, SeahorseWidget *swidget)
 
     skey = get_selected_key (swidget, &uid);
     if (SEAHORSE_IS_PGP_KEY (skey))
-        seahorse_sign_show (SEAHORSE_PGP_KEY (skey), uid);
+        seahorse_sign_show (SEAHORSE_PGP_KEY (skey), 
+                            GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)), 
+                            uid);
 }
 
 static void
 search_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
 #ifdef WITH_KEYSERVER
-    seahorse_keyserver_search_show ();
+    seahorse_keyserver_search_show (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 #endif
 }
 
@@ -756,7 +758,7 @@ sync_activate (GtkWidget *widget, SeahorseWidget *swidget)
     
     if (keys == NULL)
         keys = seahorse_context_find_keys (SCTX_APP (), SKEY_PGP, 0, SKEY_LOC_LOCAL);
-    seahorse_keyserver_sync_show (keys);
+    seahorse_keyserver_sync_show (keys,GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
     g_list_free (keys);
 #endif
 }
@@ -778,7 +780,7 @@ setup_sshkey_activate (GtkWidget *widget, SeahorseWidget *swidget)
     }    
     
     if (keys != NULL)
-        seahorse_ssh_upload_prompt (keys);
+        seahorse_ssh_upload_prompt (keys, GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 #endif 
 }
 
@@ -812,7 +814,7 @@ delete_activate (GtkWidget *widget, SeahorseWidget *swidget)
 static void
 preferences_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
-    seahorse_preferences_show (NULL);
+    seahorse_preferences_show (GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)), NULL);
 }
 
 /* Makes URL in About Dialog Clickable */
@@ -829,14 +831,14 @@ about_activate (GtkWidget *widget, SeahorseWidget *swidget)
 {
     static gboolean been_here = FALSE;
     
-	static const gchar *authors[] = {
+	const gchar *authors[] = {
 		"Jacob Perkins <jap1@users.sourceforge.net>",
 		"Jose Carlos Garcia Sogo <jsogo@users.sourceforge.net>",
 		"Jean Schurger <yshark@schurger.org>",
         "Nate Nielsen <nielsen@memberwebs.com>",
         "Adam Schreiber <sadam@clemson.edu>",
         "",
-        "Contributions:",
+        _("Contributions:"),
         "Albrecht Dreß <albrecht.dress@arcor.de>",
         "Jim Pharis <binbrain@gmail.com>",
 		NULL
@@ -888,11 +890,11 @@ row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2
 
     skey = seahorse_key_manager_store_get_key_from_path (view, path, NULL);
     if (skey != NULL)
-        show_properties (skey);
+        show_properties (skey, GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
 }
 
-static void
-selection_changed (GtkTreeSelection *notused, SeahorseWidget *swidget)
+static gboolean
+selection_changed (SeahorseWidget *swidget)
 {
     GtkTreeView *view;
     GtkWidget *tab;
@@ -985,6 +987,19 @@ selection_changed (GtkTreeSelection *notused, SeahorseWidget *swidget)
     actions = seahorse_widget_find_actions (swidget, "ssh");
     gtk_action_group_set_sensitive (actions, ktype == SKEY_SSH);
 #endif    
+    
+    /* This is called as a one-time idle handler, return FALSE so we don't get run again */
+    return FALSE;
+}
+
+static void
+selection_changed_later (GtkTreeSelection *notused, SeahorseWidget *swidget)
+{
+    /* 
+     * Due to various problems with GtkTreeModelFilter we delay the action
+     * just a bit. These problems are fixed in later versions of GTK. 
+     */
+    g_idle_add ((GSourceFunc)selection_changed, swidget);
 }
 
 static void
@@ -1071,7 +1086,7 @@ tab_changed (GtkWidget *widget, GtkNotebookPage *page, guint page_num,
     /* Don't track the selected key when tab is changed on purpose */
     g_object_set_data (G_OBJECT (swidget), TRACK_SELECTED_KEY, NULL);
     
-    selection_changed (NULL, swidget);
+    selection_changed (swidget);
     
     /* 
      * Because gnome-keyring can throw prompts etc... we delay loading 
@@ -1261,7 +1276,7 @@ initialize_tab (SeahorseWidget *swidget, const gchar *tabwidget, guint tabid,
     
     selection = gtk_tree_view_get_selection (view);
     gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-    g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), swidget);
+    g_signal_connect (selection, "changed", G_CALLBACK (selection_changed_later), swidget);
     
     /* Add new key store and associate it */
     skstore = seahorse_key_manager_store_new (skset, view);
@@ -1282,7 +1297,7 @@ seahorse_key_manager_show (SeahorseOperation *op)
     GtkActionGroup *actions;
     GtkAction *action;
     
-    swidget = seahorse_widget_new ("key-manager");
+    swidget = seahorse_widget_new ("key-manager", NULL);
     win = GTK_WINDOW (seahorse_widget_get_top (swidget));
     
     notebook = GTK_NOTEBOOK (seahorse_widget_get_widget (swidget, "notebook"));
@@ -1407,7 +1422,7 @@ seahorse_key_manager_show (SeahorseOperation *op)
     /* To show first time dialog */
     g_timeout_add (1000, (GSourceFunc)first_timer, swidget);
     
-    selection_changed (NULL, swidget);
+    selection_changed (swidget);
     
     return win;
 }
