@@ -31,6 +31,9 @@
 #include "seahorse-progress.h"
 #include "seahorse-gtkstock.h"
 
+#define DSA_SIZE 1024
+#define DEFAULT_RSA_SIZE 2048
+
 static void
 completion_handler (SeahorseOperation *op, gpointer data)
 {
@@ -42,7 +45,7 @@ completion_handler (SeahorseOperation *op, gpointer data)
 }
 
 static void
-upload_handler (SeahorseOperation *op, gpointer data)
+upload_handler (SeahorseOperation *op, SeahorseWidget *swidget)
 {
     SeahorseSSHKey *skey;
     GList *keys;
@@ -55,10 +58,29 @@ upload_handler (SeahorseOperation *op, gpointer data)
     g_return_if_fail (SEAHORSE_IS_SSH_KEY (skey));
     
     keys = g_list_append (NULL, skey);
-    seahorse_ssh_upload_prompt (keys);
+    seahorse_ssh_upload_prompt (keys, GTK_WINDOW (glade_xml_get_widget (swidget->xml, swidget->name)));
     g_list_free (keys);
 }
 
+static void
+on_change (GtkComboBox *combo, SeahorseWidget *swidget)
+{
+    const gchar *t;    
+    GtkWidget *widget;
+    
+    widget = seahorse_widget_get_widget (swidget, "bits-entry");
+    g_return_if_fail (widget != NULL);
+    
+    t = gtk_combo_box_get_active_text (combo);
+    if (t && strstr (t, "DSA")) {
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), DSA_SIZE);
+        gtk_widget_set_sensitive (widget, FALSE);
+    } else {
+        gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), DEFAULT_RSA_SIZE);
+        gtk_widget_set_sensitive (widget, TRUE);
+    }
+}
+
 static void
 on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
 {
@@ -115,26 +137,26 @@ on_response (GtkDialog *dialog, guint response, SeahorseWidget *swidget)
     op = seahorse_ssh_operation_generate (src, email, type, bits);
     g_return_if_fail (op != NULL);
     
-    seahorse_widget_destroy (swidget);
-    
     /* Watch for errors so we can display */
     seahorse_operation_watch (op, G_CALLBACK (completion_handler), NULL, NULL);
     
     /* When completed upload */
     if (upload)
-        seahorse_operation_watch (op, G_CALLBACK (upload_handler), NULL, NULL);
+        seahorse_operation_watch (op, G_CALLBACK (upload_handler), NULL, swidget);
+    
+    seahorse_widget_destroy (swidget);
     
     seahorse_progress_show (op, _("Creating Secure Shell Key"), TRUE);
     g_object_unref (op);
 }
 
 void
-seahorse_ssh_generate_show (SeahorseSSHSource *src)
+seahorse_ssh_generate_show (SeahorseSSHSource *src, GtkWindow *parent)
 {
     SeahorseWidget *swidget;
     GtkWidget *widget;
     
-    swidget = seahorse_widget_new ("ssh-generate");
+    swidget = seahorse_widget_new ("ssh-generate", parent);
     
     /* Widget already present */
     if (swidget == NULL)
@@ -151,6 +173,9 @@ seahorse_ssh_generate_show (SeahorseSSHSource *src)
     g_object_ref (src);
     g_object_set_data_full (G_OBJECT (swidget), "key-source", src, g_object_unref);
     
+    g_signal_connect (G_OBJECT (seahorse_widget_get_widget (swidget, "algorithm-choice")), "changed", 
+                    G_CALLBACK (on_change), swidget);
+    
     g_signal_connect (seahorse_widget_get_top (swidget), "response", 
                     G_CALLBACK (on_response), swidget);
 }
